@@ -537,7 +537,9 @@ class PageObjectGenerator:
         """
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
         raw_title = self._get_name_property(title)
-        class_name = unidecode((self._normilize_to_camel_case(raw_title)))
+        translated = self._translate(raw_title)
+        class_name = self._normilize_to_camel_case(translated)
+
         title_locator = self._node_to_locator(title)
         recycler_locator = self._node_to_locator(recycler) if recycler else None
 
@@ -685,10 +687,16 @@ class PageObjectGenerator:
                 used_ids.add(anchor.id)
                 self.logger.debug(f"Added summary anchor: {base_name} → {anchor_prop['locator']}")
             else:
-                base_name = next(
-                    (p["name"] for p in properties if p["element_id"] == anchor.id),
-                    self._generate_property_name(anchor, used_names)
-                )
+                base_name = None
+                for p in properties:
+                    if p.get("element_id") == anchor.id:
+                        base_name = p["name"]
+                        self.logger.debug(f"[Find base_name] matched property: name={base_name}, id={anchor.id}")
+                        break
+                if base_name is None:
+                    self.logger.debug(f"[Find base_name] no match found, generating new name")
+                    base_name = self._generate_property_name(anchor, used_names)
+                    self.logger.debug(f"[Find base_name] generated name: {base_name}")
 
             if summary.id in used_ids:
                 continue
@@ -696,6 +704,7 @@ class PageObjectGenerator:
             prop = {
                 "type": "summary",
                 "name": name,
+                "element_id": anchor.id,
                 "locator": self._node_to_locator(anchor),
                 "sibling": True,
                 "summary_id": self._node_to_locator(summary, only_id=True),
@@ -793,6 +802,8 @@ class PageObjectGenerator:
             text = node.attrs.get("text") or node.attrs.get("content-desc") or ""
             if not text and node.attrs.get("resource-id"):
                 text = self._strip_package_prefix(node.attrs['resource-id'])
+            if self.translator is not None:
+                text = self._translate(text)
             words = self._slug_words(text)[:5]
             base = "_".join(words) if words else "element"
 
